==> Pyrogram-0.6.4-py3-none-any.whl: pyrogram/api/functions/messages/get_all_stickers.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class GetAllStickers(Object):
    """
    Attributes:
        ID (:obj:`int`): ``0x1c9618b1``

    Args:
        hash: :obj:`int`

    Returns:
        :class:`pyrogram.api.types.messages.AllStickersNotModified` | :class:`pyrogram.api.types.messages.AllStickers`

    Raises:
        :class:`pyrogram.Error`
    """
    ID = 0x1c9618b1

    def __init__(self, hash):
        self.hash = hash  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "GetAllStickers":
        # No flags
        
        hash = Int.read(b)
        
        return GetAllStickers(hash)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.hash))
        
        return b.getvalue()

==> Pyrogram-0.7.1-py3-none-any.whl: pyrogram/api/functions/messages/get_all_stickers.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class GetAllStickers(Object):
    """Attributes:
        ID: ``0x1c9618b1``

    Args:
        hash: ``int`` ``32-bit``

    Raises:
        :obj:`Error <pyrogram.Error>`

    Returns:
        Either :obj:`essages.AllStickersNotModified <pyrogram.api.types.essages.AllStickersNotModified>` or :obj:`essages.AllStickers <pyrogram.api.types.essages.AllStickers>`
    """
    ID = 0x1c9618b1

    def __init__(self, hash):
        self.hash = hash  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "GetAllStickers":
        # No flags
        
        hash = Int.read(b)
        
        return GetAllStickers(hash)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.hash))
        
        return b.getvalue()
